# peachiia-pypi

A Frankenstein's monster of code. Mostly useless modules sewn together, with a few sparks of potential. Enter at your own risk (and for the LOLs). Published to PyPI, aka. pip.

    python setup.py sdist bdist_wheel

    pip install --force-reinstall dist/peachiia-0.0.1-py3-none-any.whl

    python example.py